<template>
  <div class="container-fluid pb-5 mb-5">
    <div class="row p-4 ">
      <div class="col-lg-10">
        <div class="text-center mb-5">
          <h1 class="mb-3">{{ t('account.business.create.index.title') }}</h1>
          <p class="text-muted">
            {{ t('account.business.create.index.description') }}
          </p>
        </div>
        <template v-if="data.loaded">

          <div class="row g-4">
            <div class="col-md-6 col-lg-6" v-for="(type,index) in data.types" :key="index">
              <nuxt-link :to="'/account/business/create/' + type.slug">
                <div class="card h-100 shadow-sm">
                  <div class="card-body position-relative">
                    <h5 class="card-title">{{ type.title }}</h5>
                    <p class="card-text fw-light mb-5">
                      {{ t('account.business.create.index.card.description', { name: type.title }) }}
                    </p>
                    <i :class="'icon icon-regular-' + type.icon + ' font-size-50 text-default position-absolute bottom-20-px left-20-px'"></i>
                  </div>
                </div>
              </nuxt-link>
            </div>
          </div>
        </template>

        <template v-else>
          <client-only>
            <div class="row">
              <div v-for="i in 4" :key="i" class="col-lg-6 my-2">
                <div class="card horizontal-card h-100 min-h-160-px shadow-sm">
                  <div class="card-body p-0">
                    <div class="row h-100">
                      <div class="col-6 ps-0 py-3">
                        <div class="px-3 h-100 d-flex align-items-start justify-content-start flex-column">
                          <shimmer height="20" class="my-2 rounded"/>
                          <div class="mt-auto">
                            <p class="card-text text-muted mb-1 font-size-14">
                              <shimmer height="15" class="my-2 rounded"/>
                            </p>
                            <shimmer height="10" class="my-2 rounded"/>
                          </div>
                        </div>
                      </div>
                      <div class="col-6 pe-0">
                        <div class="p-3">
                          <shimmer height="120" class="my-2 rounded"/>
                        </div>
                      </div>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </client-only>
        </template>
      </div>
    </div>
  </div>
</template>

<script setup>
import {useI18n} from 'vue-i18n'
import {onMounted, reactive} from "vue";

const {t} = useI18n()
const {$api} = useNuxtApp();

const data = reactive({
  loaded: false,
  types: [],
})

definePageMeta({
  middleware: ['auth']
});

const getType = async () => {
  data.loaded = false;
  await $api.post('/business_type').then((value) => {
    data.types = value.data.data;

    data.loaded = true;
  })
}

onMounted(() => {
  getType();
})

</script>

<style scoped></style>
